api.customers.v1.test_helpers.location package — Argus-Toolbelt 1.0 documentation

# api.customers.v1.test_helpers.location package

## Submodules

## api.customers.v1.test_helpers.location.get_customer_locations module

`api.customers.v1.test_helpers.location.get_customer_locations.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/location, respond with HTTP 403

`api.customers.v1.test_helpers.location.get_customer_locations.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/location, respond with HTTP 404

`api.customers.v1.test_helpers.location.get_customer_locations.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/location, respond with HTTP 200

`api.customers.v1.test_helpers.location.get_customer_locations.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/location, respond with HTTP 401

## Module contents